@@ -21,4 +21,12 @@ def fetch_results(simulation_id, conn):
 
   results = pd.DataFrame(functools.reduce(operator.iconcat, serialized_results, []))
 
-  return results
\ No newline at end of file
+  return results
+
+def import_csv(file_name):
+  raw = pd.read_csv(file_name)
+  df = pd.DataFrame()
+  for idx, row in raw.iterrows():
+    df = df.append(pickle.loads(bytes.fromhex(row['data'])))
+
+  return df
\ No newline at end of file
